// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module requires `dataset-foaf` feature to be enabled.

use crate::dataset_from_path;

dataset_from_path!("../../ontologies/foaf.nq");
